@@ -85,22 +85,37 @@ def ensure_aiter(
     if isinstance(it, AsyncIterable):
         return aiter(it)
     if isgenerator(it):
-        send = ensure_async(it.send, threaded=threaded)
-        async def wrapper():
-            e: Any = None
-            try:
-                while True:
-                    e = yield await send(e)
-            except StopAsyncIteration:
-                pass
+        if threaded:
+            send = as_thread(it.send)
+            async def wrapper():
+                e: Any = None
+                try:
+                    while True:
+                        e = yield await send(e)
+                except StopAsyncIteration:
+                    pass
+        else:
+            send = it.send
+            async def wrapper():
+                e: Any = None
+                try:
+                    while True:
+                        e = yield send(e)
+                except StopIteration:
+                    pass
     else:
-        get = ensure_async(iter(it).__next__, threaded=threaded)
-        async def wrapper():
-            try:
-                while True:
-                    yield await get()
-            except:
-                pass
+        if threaded:
+            get = as_thread(iter(it).__next__)
+            async def wrapper():
+                try:
+                    while True:
+                        yield await get()
+                except StopAsyncIteration:
+                    pass
+        else:
+            async def wrapper():
+                for e in it:
+                    yield e
     return wrapper()
 
 
